==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1GCEPersistentDiskVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1GCEPersistentDiskVolumeSourceFluentImpl<A extends V1GCEPersistentDiskVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1GCEPersistentDiskVolumeSourceFluent<A>{

    private String fsType;
    private Integer partition;
    private String pdName;
    private Boolean readOnly;

    public V1GCEPersistentDiskVolumeSourceFluentImpl(){
    }
    public V1GCEPersistentDiskVolumeSourceFluentImpl(V1GCEPersistentDiskVolumeSource instance){
            this.withFsType(instance.getFsType());

            this.withPartition(instance.getPartition());

            this.withPdName(instance.getPdName());

            this.withReadOnly(instance.isReadOnly());

    }

    public String getFsType(){
            return this.fsType;
    }

    public A withFsType(String fsType){
            this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType(){
            return this.fsType != null;
    }

    public Integer getPartition(){
            return this.partition;
    }

    public A withPartition(Integer partition){
            this.partition=partition; return (A) this;
    }

    public Boolean hasPartition(){
            return this.partition != null;
    }

    public A withNewPartition(int arg1){
            return (A)withPartition(new Integer(arg1));
    }

    public A withNewPartition(String arg1){
            return (A)withPartition(new Integer(arg1));
    }

    public String getPdName(){
            return this.pdName;
    }

    public A withPdName(String pdName){
            this.pdName=pdName; return (A) this;
    }

    public Boolean hasPdName(){
            return this.pdName != null;
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1GCEPersistentDiskVolumeSourceFluentImpl that = (V1GCEPersistentDiskVolumeSourceFluentImpl) o;
            if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
            if (partition != null ? !partition.equals(that.partition) :that.partition != null) return false;
            if (pdName != null ? !pdName.equals(that.pdName) :that.pdName != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1GCEPersistentDiskVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1GCEPersistentDiskVolumeSourceFluentImpl<A extends V1GCEPersistentDiskVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1GCEPersistentDiskVolumeSourceFluent<A>{

    private String fsType;
    private Integer partition;
    private String pdName;
    private Boolean readOnly;

    public V1GCEPersistentDiskVolumeSourceFluentImpl(){
    }
    public V1GCEPersistentDiskVolumeSourceFluentImpl(V1GCEPersistentDiskVolumeSource instance){
            this.withFsType(instance.getFsType());

            this.withPartition(instance.getPartition());

            this.withPdName(instance.getPdName());

            this.withReadOnly(instance.isReadOnly());

    }

    public String getFsType(){
            return this.fsType;
    }

    public A withFsType(String fsType){
            this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType(){
            return this.fsType != null;
    }

    public A withNewFsType(String arg1){
            return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuilder arg1){
            return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuffer arg1){
            return (A)withFsType(new String(arg1));
    }

    public Integer getPartition(){
            return this.partition;
    }

    public A withPartition(Integer partition){
            this.partition=partition; return (A) this;
    }

    public Boolean hasPartition(){
            return this.partition != null;
    }

    public String getPdName(){
            return this.pdName;
    }

    public A withPdName(String pdName){
            this.pdName=pdName; return (A) this;
    }

    public Boolean hasPdName(){
            return this.pdName != null;
    }

    public A withNewPdName(String arg1){
            return (A)withPdName(new String(arg1));
    }

    public A withNewPdName(StringBuilder arg1){
            return (A)withPdName(new String(arg1));
    }

    public A withNewPdName(StringBuffer arg1){
            return (A)withPdName(new String(arg1));
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1GCEPersistentDiskVolumeSourceFluentImpl that = (V1GCEPersistentDiskVolumeSourceFluentImpl) o;
            if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
            if (partition != null ? !partition.equals(that.partition) :that.partition != null) return false;
            if (pdName != null ? !pdName.equals(that.pdName) :that.pdName != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            return true;
    }




}
